'use client'
import useShowToast from '@/app/hooks/useShowToast';
import { editCaseRequest } from '@/app/lib/cases/action';
import { createKycRequest } from '@/app/lib/kyc/action';
import { SelectWrapper, SelectWrapperWithExtraFields } from '@/components/fields/Fields';
import FormComponent from '@/components/form/Form';
import prepareValidationSchema from '@/utils/validation-schema';
import { Box, Button, FormControl, FormLabel, Text, useColorModeValue } from "@chakra-ui/react";
import { useRouter } from 'next/navigation';
import { useEffect, useRef, useState } from 'react';
import { AttemptedInterface } from '../type/attempted';
import { formFields } from '../variables/formFields';
import { useFormikContext } from 'formik';
import { storeAttempt } from '@/app/lib/attempt/action';


interface KycInterface {
    full_name: string;
    id: number;

}
interface AssignmentInterface {
    days: string;
    id: number;
}

interface ConsumerInterface {
    contact_person: string;
    id: number;
}

interface formProps {
    isEdit: AttemptedInterface,
    assignment: AssignmentInterface[],
    kycs: KycInterface[],
    consumers: ConsumerInterface[],
}

interface Location {
    latitude: string;
    longitude: string;
}

const AttemptedForm = ({ isEdit, assignment, kycs, consumers }: formProps) => {
    const formRef = useRef(null);
    const router = useRouter();
    const showToast = useShowToast();
    const textColor = useColorModeValue("navy.700", "white");
    const brandStars = useColorModeValue("brand.500", "brand.400");
    const [loading, setLoading] = useState(false);
    const [location, setLocation] = useState<Location>({ latitude: '', longitude: '' });
    const [obj, setObj] = useState<any>(null);

    const formDetails = prepareValidationSchema(formFields);
    const { initialFormData, validationSchema } = formDetails;

    // Set initial values based on whether we are adding or editing
    const initialValues = isEdit ? { ...isEdit } : initialFormData;

    const handleSubmitClick = () => {
        formRef?.current?.externalHandleSubmit();
    };

    const getLocation = () => {
        if (navigator.geolocation) {
            navigator.geolocation.getCurrentPosition(
                (position: GeolocationPosition) => {
                    setLocation({
                        latitude: position.coords.latitude.toString(),
                        longitude: position.coords.longitude.toString(),
                    });

                },
                (error: GeolocationPositionError) => {
                    showToast("Failed", 'Unable to retrieve location', "error");
                    // router.back();
                }
            );
        } else {
            showToast("Failed", 'Geolocation is not supported by this browser', "error");
        }
    };


    const handleCreate = async (values: FormData) => {
        try {
            const response = await storeAttempt(values);
            if (response) {
                router.push("/officer/attempted");
            }
            showToast("Attempted Created!", response.message, "success");
        } catch (error: any) {
            showToast("Failed to create", error.message, "error");
        } finally {
            setLoading(false);
        }
    };



    const handleSubmit = (values: FormData) => {
        values['case_id'] = obj?.case_id
        values['batch_id'] = obj?.batch_id ? obj?.batch_id : 1

        handleCreate(values);
    };

    useEffect(() => {
        getLocation()
    }, [])

    console.log("location", obj);

    return (
        <>
            <FormComponent
                ref={formRef}
                validationSchema={validationSchema}
                initialValues={initialValues}
                // enableReinitialize // Ensures the form reinitializes with updated initial values
                submitForm={handleSubmit}

            >

                <Box display="flex" gap={15}>
                    <FormControl w="50%">
                        <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                            Assignment &nbsp;<Text display="inline-block" color={brandStars}>*</Text>
                        </FormLabel>
                        <SelectWrapperWithExtraFields
                            form
                            fieldName="assignment_id"
                            extraFields={{ case: "case_id", batch: "batch_id" }}
                            setObj={setObj}
                            defaultValue={isEdit?.assignment_id}
                            id="assignment_id"
                            variant="auth"
                            w="full"
                            mb="2px"
                            fontSize="sm"
                            fontWeight="500"
                            options={assignment?.map((item: any) => ({ label: item.days, value: item.id, ...item }))}

                        />
                    </FormControl>

                </Box>

                <Box display="flex" gap={15}>
                    <FormControl w="50%">
                        <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                            KYC &nbsp;<Text display="inline-block" color={brandStars}>*</Text>
                        </FormLabel>
                        <SelectWrapper
                            form
                            fieldName="kyc_id"
                            defaultValue={isEdit?.kyc_id}
                            id="kyc_id"
                            variant="auth"
                            w="full"
                            mb="2px"
                            fontSize="sm"
                            fontWeight="500"
                            options={kycs?.map((item: any) => ({ label: item.full_name, value: item.id }))}
                        />
                    </FormControl>
                </Box>

                <Box display="flex" gap={15}>
                    <FormControl w="50%">
                        <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                            Consumer &nbsp;<Text display="inline-block" color={brandStars}>*</Text>
                        </FormLabel>
                        <SelectWrapper
                            form
                            fieldName="consumer_id"
                            defaultValue={isEdit?.consumer_id}
                            id="consumer_id"
                            variant="auth"
                            w="full"
                            mb="2px"
                            fontSize="sm"
                            fontWeight="500"
                            options={consumers?.map((item: any) => ({ label: item.contact_person, value: item.id }))}
                        />
                    </FormControl>
                </Box>


                <Button variant="brand" onClick={handleSubmitClick} mr={3} isDisabled={loading}>
                    {isEdit ? "Save" : "Create"}
                </Button>

            </FormComponent>

        </>
    )
}

export default AttemptedForm